# yambo-aiida  
AiiDA plugin and workchains for the YAMBO code

## Installation instructions:

Requirements AiiDA (version >= 0.9.0).

Installation via pip

``` 
pip install -e yambo-aiida
reentry scan
```

For workflows:  

    `Place the folder `wf` in   aiida/workflows/user/cnr_nano`


Examples:  
    *Plugin Examples are located in:  
     -examples/test_plugin
 
Documentation is available at: https://aiida-yambo.readthedocs.io/en/latest
   
